bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 17. Aventiure
___________________________________________________ #### Aventivre wie chriemhilt ir man klagte #### vnd wie man in begrvp
###### 1002 | ### Do erbiten si der nahte | vnd fvren vber rin ### von helden chvnde nimmer | wirs geiaget sin ### ein tier daz si slvgen | daz weinten edliv chint ### ia mvsen sin engelten | vil gvte wigande sint
###### 1003 | ### von grozer vebermvete | mveget ir horen sagen ### vnd von eislicher rache | do hiez hagen tragen ### sifrit also toten | von nibelvnge lant ### fver eine chaemenaten | da man criemhilde vant
###### 1004 | ### er hiez in tovgenlichen | legen an di tver ### daz sin da solde vinden | so si gienge dafver ### zer mettine | e daz ez wurde tach ### der div vrowe criemhilt | vil selten deheine verlach
###### 1005 | ### man lvte da cem mvenster | nach gewoneheit ### vrov criemhilt div schoene | wachte manige meit ### ein lieht bat si ir bringen | vnd ovch ir gewant ### do chom ein kameraere | da er sifriden vant
###### 1006 | ### er sah in blvtes roten | sin wat was elliv naz ### daz ez sin herre waere | nine wesse er daz ### hin cer kemenaten | daz lieht trvg er an der hant ### von dem vil leidem maere | div vrov criemhilt ervant
###### 1007 | ### do si mit ir vrowen | cem mvnster wolde gan ### do sprach der chameraere | ir svlt stille stan ### ez lit vor disem gadme | ein ritter tot erslagen ### do begonde criemhilt | vil harte vmmaezliche chlagen
###### 1008 | ### e daz si reht erfvnde | daz iz waere ir man ### an di hagenen vrage | denchen si began ### wi er in solde vristen | do wart ir erste leit ### von ir was allen vrevden | von sinem tode widerseit
###### 1009 | ### do seich si zv der erden | daz si niht en sprach ### di schoenen vrevdelosen | ligen man do sach ### criemhilde iamer | wart vmmazen groz ### do erschre si nach vncreffte | daz al div chemenate erdoz
###### 1010 | ### do sprach daz gesinde | waz ob ez ist ein gast ### daz blvt ir vz dem mvnde | von herceniamer brast ### do sprach si ez ist sifrit | der min vil lieber man ### ez hat geraten prvennhilt | daz ez hat hagen getan
###### 1011 | ### do vrowe hiez sich wisen | da si den helt vant ### si hop sin hovbt schoene | mit ir vil wizzen hant ### swi rot ez waere von blvte | si het in schiere erchant ### do lach vil iemerliche | der helt von nibelvnge lant
###### 1012 | ### do rief vil trvrechliche | div vrowe milt ### owe mich mines leides | nv ist dir din shilt ### mit swerten niht verhowen | div list ermorderot ### wesse ich wer iz het getan | ich riet im immer sinen tot
###### 1013 | ### allez ir gesinde | chlagete vnd schre ### mit ir lieben vrowen | wande in was harte we ### vmb ir vil edeln herren | den si da heten velorn ### da het gerochen hagene | harte prvnnhilde zorn
###### 1014 | ### do sprach div iamerhaffte | ir kameraere ir svlt hin gan ### vnd wechet harte balde | die sifrides man ### ir svlt ovch sigemvnde | minen iamer sagen ### ob er mir helffen welle | den chvenen sifride chlagen
###### 1015 | ### do lief ein bote balde | da er si ligen vant ### di sifrides helde | von nibelvnge lant ### mit den vil leiden maren | ir vrevd er in benam ### si ne wolt es niht gelovben | vnz man daz weinen vernam
###### 1016 | ### der bote chom ovch schiere | da der chvnich lach ### sigemvnt der herre | der slaffes niht en pflach ### ich waene sin herce im sagte | daz im was geschehen ### ern mohte sinen lieben svn | nimmer lebendich gesehen
###### 1017 | ### vachet herre sigemvnt | mich bat nach iv gan ### criemhilt min vrowe | der ist ein leit getan ### daz ir vor allen leiden | an ir herce gat ### daz svlt ir chlagen helffen | wand ez ivch sere bestat
###### 1018 | ### vf rihte sich do sigemvnt | er sprach waz sint div leit ### der schonen criemhilde | div dv mir hast geseit ### der bote sprach mit weinen | ine chan iv niht verdagen ### ia ist von niderlande | der chvene sifrit erslagen
###### 1019 | ### do sprach der herre sigemvnt | lat iwer schimpfen sin ### vnd also bosiv maere | dvrch willen min ### daz ir ez saget iemen | daz er si erslagen ### wand ine chvnd in nimmer | vor minem tode verchlagen
###### 1020 | ### welt ir mir niht gelovben | daz ir mir horet sagen ### so mvget ir selbe hoeren | criemhilde klagen ### vnt allez ir gesinde | den sifrides tot ### vil ser scrachte do sigemvnt | des gie im werliche not
###### 1021 | ### mit hvndert sinen mannen | er von dem bette spranch ### si zvchten zv den henden | div scharffen waffen lanch ### si lieffen zv dem wuffe | vil iamerliche dan ### do chomen tvsent rechen | des chvenen sifrides man
###### 1022 | ### do si so iaemerliche | di vrowen horten chlagen ### do wanden svemeliche | si solden chleider tragen ### ia ne mohten si der sinne | vor leide niht gehaben ### in wart vil michel swaere | in ir hercen begraben
###### 1023 | ### do chom der chvene sigemvnt | da er criemhilde vant ### er sprach owe der reise | her in dize lant ### wer hat mich mines chindes | vnd ivch des iweren man ### bi also gvten frivnden | svs mortliche anegetan
###### 1024 | ### hey sold ich den bechennen | sprach daz vil edel wip ### holt wurde im nimmer | min herce vnt ovch min lip ### ich geriete im also leide | daz di frivnde sin ### von den minen schvlden | mvsen weinende sin
###### 1025 | ### sigemvnt der herre | den fvrsten vmbesloz ### do wart von sinen vrivnden | der iamer also groz ### daz von dem starchem wuffe | palas vnde sal ### vnd ovch di stat ce wormze | von ir weinen erschal
###### 1026 | ### do ne niemen getroesten | daz sifrides wip ### man zoch vz den chleidern | den sinen lip ### man wusch im sine wunden | vnd leit in vf den re ### do was den sinen livten | von grozem iamer starche we
###### 1027 | ### do sprachen sine rechen | von nibelvnge lant ### in sol immer rechen | mit willen vnser hant ### er ist in dirre bverge | der iz hat getan ### do ilten nach den waffen | alle sifrides man
###### 1028 | ### di vzerwelten degene | mit schilden chomen dar ### einlef hvndert rechen | di het an siner schar ### sigemvnt der herre | sines svnes tot ### den wold er gerne rechen | des gie im waerlichen not
###### 1029 | ### si ne wessen wen si solden | mit strite do bestan ### si ne taeten ez danne gvnther | vnd sine man ### mit den der herre sifrit | an daz geieide reit ### criemhilt sach si gewaffent | daz was ir groezliche leit
###### 1030 | ### swi michel waer ir iamer | vnd swi starch ir not ### do vorhte | der nibelvnge tot ### von ir brvder mannen | daz si ez vnderstvnt ### si warnt si als gvetliche | so vrivnde liebe vrivnde tvnt
###### 1031 | ### do sprach div iamers riche | min herre sigemvnt ### wes welt ir beginnen | iv ist niht rehte chvnt ### ia hat der kvenich gvnther | so manigen chvenen man ### ir welt ivch alle vliesen | svlt ir di rechen bestan
###### 1032 | ### mit vf erbvnden schilden | in was ce strite not ### div edel kvneginne | bat vnd gebot ### daz siz miden solden | di rechen vil gemeit ### do siz niht lazen wolden | ei was ir waerlichen leit
###### 1033 | ### si sprach herre sigemvnt | ir svlt iz lazen vnderstan ### vnz ez sich baz gefvege | so wil ich minen man ### immer mit iv rechen | der mir in hat benomen ### wird ich des bewiset | ich sol im schaedeliche chomen
###### 1034 | ### ez ist der vebermveten | hie bi rine vil ### davon ich iv des strites | raten niht en wil ### si habent wider einen | ie wol drizech man ### nv laz in got gelingen | als vmb vns gedienet han
###### 1035 | ### ir svlt hie beliben | vnt dolt mit mir miniv leit ### als iz tagen beginne | ir helde vil gemeit ### so helffet mir besarchen | den minen lieben man ### do sprachen di degene | daz sol werden getan
###### 1036 | ### iv en chvnde niemen | daz wunder volsagen ### von rittern vnt von vrowen | wi man di horte chlagen ### so daz man des wuffes | wart in der stat gewar ### di edelen bvrgaere | di chomen gahende dar
###### 1037 | ### si chlageten mit den gesten | want in was hart leit ### daz sifrides schvlde | in niemen het geseit ### dvrch waz der edel reche | verlvr den sinen lip ### do weinten mit den vrowen | der gvten bvrgaere wip
###### 1038 | ### smide hiez man gahen | wurchen einen sarch ### von silber vnd von golde | vil michel vnd vil starch ### man hiez in vaste spengen | mit stahel daz was gvt ### do was allen livten | harte trvrech der mvt
###### 1039 | ### div naht was cergangen | man sagte ez wolde tagen ### do hiez div edel vrowe | zv dem mvnster tragen ### sifriden den herren | den vil lieben man ### swaz er da vrivnde hete | di sach man weinende gan
###### 1040 | ### do si in cem mvnster brahten | vil der gloken chlanch ### do hort man allenthalben | vil maniges pfaffen sanch ### do chom der kvnich gvnther | mit den sinen man ### vnd ovch der grimme hagene | zv dem wuffe gegan
###### 1041 | ### er sprach vil liebiv swester | owe der leide din ### daz wir niht ane | des grozen schaden sin ### wir mvezen chlagen immer | den sifrides lip ### daz tvt ir ane schvlde | sprach daz iamerhafte wip
###### 1042 | ### waer iv darvmbe leide | son waer es niht geschehen ### ir hetet min vergezzen | des mag ich nv wol iehen ### da ich da wart gescheiden | vnt min lieber man ### daz wolde got sprach criemhilt | vnd waer iz mir selber getan
###### 1043 | ### si buten vaste ir lovgen | criemhilt begonde iehen ### swelher sich vnschvldige | der laze daz gesehen ### der sol zv der bare | vor den livten gen ### dabi mach man di warheit | harte schiere versten
###### 1044 | ### daz ist ein michel wunder | vil dicke ez noch geschiht ### swa man den mortmeilen | bi dem toten siht ### so blvtent im di wunden | als ovch da geschach ### davon man di schvlde | da ce hagene gesach
###### 1045 | ### di wunden vlvzzen sere | alsam si taten e ### di e da sere chlageten | des wart nv michel me ### do sprach der kvenich gvnther | ich wilz ivch wizzen lan ### in slvgen schachaere | hagen hat es niht getan
###### 1046 | ### mir sint di schachaere | sprach si vil wol bechant ### nv laz ez got errechen | noch siner vrivnde hant ### gvnther vnd hagene | ia habt ir iz getan ### di sifrides degene | heten gegen strite wan
###### 1047 | ### do sprach aber crimhilt | habt mit mir di not ### do chomen dise beide | da si in fvnden tot ### gere ir brvder | vnd giselher daz chint ### in triwen si in chlageten | mit den anderen sint
###### 1048 | ### si weinten innechlichen | den crimhilde man ### man solde messe singen | zv dem mvnster dan ### giengen allenthalben | wip man vnt chint ### di sin doch liht enbaren | di weinten sifriden sint
###### 1049 | ### gernot vnd giselher | di sprachen swester min ### nv troste dich nach tode | als iz doch mvz sin ### wir wellen dichs ergeczen | di wile wir geleben ### do ne chvnde ir trost deheinen | cer werlde niemen gegeben
###### 1050 | ### sin sarch der was bereitet | wol vmbe einen mitten tach ### man hvp in von der bare | da er vffe lach ### ine wolde noch div frowe | lazen niht begraben ### des mvsen al di livte | michel arbeite haben
###### 1051 | ### in einen richen pfellel | man den toten want ### ich wene man da iemen | ane weinen vant ### do chlagete hercenliche | vte ein edel wip ### vnd allez ir gesinde | den sinen waetlichen lip
###### 1052 | ### do man daz gehorte | daz man cem mvenster sanch ### vnt man in gesarchet hete | do hvp sich groz gedranch ### dvrch willen siner sele | waz opffers man do trvch ### er hete bi den vinden | doch gvter vrivnde genvch
###### 1053 | ### criemhilt div arme | cen kameraeren sprach ### si svln dvrch mine liebe | liden vngemach ### di im iht gvtes gvennen | vnd mir wesen holt ### dvrch sifrides sele | sol man teilen sin golt
###### 1054 | ### dehein chint was da so chleine | daz iht witze mohte haben ### daz mvse gen cem opffer | e wurde begraben ### baz danne hvndert messe | man da des tages sanch ### von sifrides vrivnden | wart da grozer gedranch
###### 1055 | ### do man da hete gesvngen | daz volch hvp sich von dan ### do sprach div vrowe criemhilt | irn svlt eine lan ### hinte mich bewachen | den vzerwelten degen ### ez ist an sinem libe | al min vrevde gelegen
###### 1056 | ### dri tage vnd dri nahte | wil ich lazen stan ### vnz ich mich geniete | mines vil lieben man ### waz ob daz got gebivtet | daz mich nimt ovch der tot ### so waere wol verendet | min armer criemhilde not
###### 1057 | ### cen herbergen giengen | di livte von der stat ### pfaffen vnd mvenche | si beliben bat ### vnd allez sin gesinde | daz ez des heldes pflach ### si heten naht vil arge | vnt vil mvelichen tach
###### 1058 | ### ane ezzen vnd ane trinchen | beleip da manich man ### di ez da nemen wolden | den wart daz chvnt getan ### daz mans in den vollen gaebe | daz schvf her sigemvnt ### do was den nibelvngen | vil arbeite chvnt
###### 1059 | ### di drie tagecite | so wir horen sagen ### di da chvnden singen | daz si mvsen tragen ### vil der arbeite | waz man in opfers trvch ### di vil arme waren | di wurden riche genvch
###### 1060 | ### swaz man vant der armen | di es niht mohten han ### di hei man cem opfer | mit dem golde gan ### vz sin selbes kamern | do er niht solde leben ### vmb sine sele | wart manich tvsent march gegeben
###### 1061 | ### vrbor vf der erden | teilten si in div lant ### swa so man div kloster | vnd gvte livte vant ### silbers vnd waete | gap man den armen genvch ### si tet dem wol geliche | daz sim holden willen trvch
###### 1062 | ### an den drittem morgen | ce der rehten messecit ### so was bi dem mvnster | der chirchof also wit ### von den lantlivten | weinens also vol ### si dienten im nach tode | also man lieben vrivnden sol
###### 1063 | ### in den tagen vieren | man hat gesaget daz ### ce drizech tvsent marchen | oder dannoch baz ### wart dvrch sine sele | den armen da gegebn ### do was gelegen ringe | sin groziv schone vnd ovch sin leben
###### 1064 | ### do got da wart gedienet | daz man vol sanch ### mit vngefvegem leide | vil des volches ranch ### man hiez in vz dem mvenster | zv dem grabe tragen ### di sin vngern enbaren | di sah man weinen vnd chlagen
###### 1065 | ### vil lvte schriende | daz livt gi mit im dan ### vro en was da niemen | weder wip noch man ### e daz man in begrvebe | man sanch vnd las ### hey waz gvter pfaffen | ce siner pifilde was
###### 1066 | ### e daz cem grabe choeme | daz sifrides wip ### do ranch so mit iamer | ir getriwer lip ### daz man si mit dem brvnnen | vil dicke da vergoz ### ez was ir vngemvete | vil harte vnmaezlichen groz
###### 1067 | ### ez was ein michel wunder | daz si ie genas ### mit chlage ir helfende | manich vrowe was ### do sprach div chveneginne | ir sifrides man ### ir svlt dvrch iwer triwe | an mir genade began
###### 1068 | ### lat mir nach minem leide | daz chleine liep geschehen ### daz ich sin schoene hovbt | noch eines mveze sehen ### do bat sis also lange | mit iamers sinnen starch ### daz man cebrechen mvse | do den herlichen sarch
###### 1069 | ### do brahte man di vrowen | da si in ligen vant ### si hvp sin schoene hovbt | mit ir vil wizzen hant ### do chvstes also toten | den edel ritter gvt ### div ir vil liehten ovgen | vor leide weinten blvt
###### 1070 | ### ein iamergez scheiden | wart do da getan ### do trvch man si von dannen | si ne chvnde niht gegan ### do vant man sinnelose | daz herliche wip ### vor leide moht ersterben | der ir vil wunnechlicher lip
###### 1071 | ### do man den edelen herren | hete nv begraben ### leit ane maze | sah man di alle haben ### di mit im chomen waren | von nibelvnge lant ### vil selten vroelichen | man do sigemvnden vant
###### 1072 | ### da was der etelicher | der drier tage lanch ### vor dem grozem leide | niht az noch en tranch ### do mohten si dem libe | so gar geswichen niht ### si nerten sich nach sorgen | so noch genvgen gesiht

<<< Übersicht <<< vorige Seite nächste Seite >>>